@@ -3,7 +3,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.007010'; # VERSION
+our $VERSION = '0.007011'; # VERSION
 
 1;
 
@@ -19,7 +19,7 @@ Business::CyberSource - Perl interface to the CyberSource Simple Order SOAP API
 
 =head1 VERSION
 
-version 0.007010
+version 0.007011
 
 =head1 DESCRIPTION
 
@@ -93,11 +93,15 @@ A test credit card number provided by your your credit card processor
 	my $client = Business::CyberSource::Client->new({
 		username   => 'Merchant ID',
 		password   => 'API Key',
-		production => 1,
+		production => 0,
+		debug      => 1, # do not set in production as it prints sensative
+                         # information
 	});
 
-	my $auth_request = try {
-			Business::CyberSource::Request::Authorization->new({
+	my $auth_request;
+	try {
+		$auth_request
+			= Business::CyberSource::Request::Authorization->new({
 				reference_code => '42',
 				bill_to => {
 					first_name  => 'Caleb',
@@ -121,25 +125,20 @@ A test credit card number provided by your your credit card processor
 					},
 				},
 			});
-		}
-		catch {
-			carp $_;
-		};
+	}
+	catch {
+		carp $_;
+	};
+	return unless $auth_request;
 
-	my $auth_response = try {
-			$client->run_transaction( $auth_request );
-		}
-		catch {
-			carp $_;
-
-			if ( $auth_request->has_trace ) {
-				carp 'REQUEST: '
-				. $auth_request->trace->request->as_string
-				. 'RESPONSE: '
-				. $auth_request->trace->response->as_string
-				;
-			}
-		};
+	my $auth_response;
+	try {
+		$auth_response = $client->run_transaction( $auth_request );
+	}
+	catch {
+		carp $_;
+	};
+	return unless $auth_response;
 
 	unless( $auth_response->is_accept ) {
 		carp $auth_response->reason_text;
@@ -157,20 +156,14 @@ A test credit card number provided by your your credit card processor
 				},
 			});
 
-		my $capture_response = try {
-			$client->run_transaction( $capture_request );
+		my $capture_response;
+		try {
+			$capture_response = $client->run_transaction( $capture_request );
 		}
 		catch {
 			carp $_;
-
-			if ( $capture_request->has_trace ) {
-				carp 'REQUEST: '
-				. $capture_request->trace->request->as_string
-				. 'RESPONSE: '
-				. $capture_request->trace->response->as_string
-				;
-			}
 		};
+		return unless $capture_response;
 
 		if ( $capture_response->is_accept ) {
 			# you probably want to record this
@@ -209,8 +202,7 @@ for the help with getting L<XML::Compile::SOAP::WSS> working.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/hostgator/business-cybersource/issues or by email to
-development@hostgator.com.
+https://github.com/xenoterracide/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -222,7 +214,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
 
 This is free software, licensed under:
 
