@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007010'; # VERSION
+our $VERSION = '0.007011'; # VERSION
 
 use Moose;
 
@@ -310,7 +310,7 @@ Business::CyberSource::Client - User Agent Responsible for transmitting the Resp
 
 =head1 VERSION
 
-version 0.007010
+version 0.007011
 
 =head1 SYNOPSIS
 
@@ -363,15 +363,15 @@ C<PERL_BUSINESS_CYBERSOURCE_DEBUG>.
 
 =over
 
-=item 0
+=item value 0
 
 no output (default)
 
-=item 1
+=item value 1
 
 request/response hashref
 
-=item 2
+=item value 2
 
 1 plus actual HTTP and XML
 
@@ -418,8 +418,7 @@ CyberSource API version, currently 1.71
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/hostgator/business-cybersource/issues or by email to
-development@hostgator.com.
+https://github.com/xenoterracide/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -431,7 +430,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
 
 This is free software, licensed under:
 
