@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.007010'; # VERSION
+our $VERSION = '0.007011'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::MessagePart';
@@ -91,7 +91,7 @@ Business::CyberSource::RequestPart::Item - Item Helper Class
 
 =head1 VERSION
 
-version 0.007010
+version 0.007011
 
 =head1 EXTENDS
 
@@ -154,8 +154,7 @@ The total amount authorized will be 32.40, not 30.00 with 2.40 of tax included.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/hostgator/business-cybersource/issues or by email to
-development@hostgator.com.
+https://github.com/xenoterracide/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -167,7 +166,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
 
 This is free software, licensed under:
 
