@@ -4,7 +4,7 @@ use warnings;
 use namespace::autoclean;
 use Module::Load 'load';
 
-our $VERSION = '0.007010'; # VERSION
+our $VERSION = '0.007011'; # VERSION
 
 use Moose;
 extends 'Business::CyberSource::Message';
@@ -350,7 +350,7 @@ Business::CyberSource::Response - Response Object
 
 =head1 VERSION
 
-version 0.007010
+version 0.007011
 
 =head1 SYNOPSIS
 
@@ -499,8 +499,7 @@ B<Type:> L<Business::CyberSource::ResponsePart::TaxReply>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/hostgator/business-cybersource/issues or by email to
-development@hostgator.com.
+https://github.com/xenoterracide/business-cybersource/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -512,7 +511,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by L<HostGator.com|http://hostgator.com>.
+This software is Copyright (c) 2013 by L<HostGator.com|http://hostgator.com>.
 
 This is free software, licensed under:
 
